# Causalis - Modern Reproducible Causal Analysis <a href="https://ioannmartynov.github.io/CausalKit/"><img src="https://raw.githubusercontent.com/IoannMartynov/CausalKit/main/docs/_static/logo_big.svg" alt="CausalKit logo" width="80" style="float: left; margin-right: 10px;" /></a>
[![Docs](https://github.com/IoannMartynov/CausalKit/actions/workflows/deploy-docs.yml/badge.svg?branch=main)](https://github.com/IoannMartynov/CausalKit/actions/workflows/deploy-docs.yml)
![Python](https://img.shields.io/badge/python-3.10%20|%203.11%20|%203.12-blue)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)
![Code quality](https://img.shields.io/badge/code%20quality-A-brightgreen)

## [Official Documentation and Examples](https://ioannmartynov.github.io/Causalis/index.html)

## Installation

Install from github directly

```bash
pip install git+https://github.com/ioannmartynov/causalis.git
```




# Scenarios Covered
| Is RCT        | Treatment | Outcome    | EDA | Estimands | Refutation | Docs                                                                      |
|---------------|-----------|------------|-----|-----------|------------|---------------------------------------------------------------------------|
| Observational | Binary    | Continuous | Yes | ATE       | Yes        | [Example](https://ioannmartynov.github.io/Causalis/examples/dml_ate.html) |
| Observational | Binary    | Continuous | Yes | ATT       | Yes        | [Example](https://ioannmartynov.github.io/Causalis/examples/dml_att.html) |

# Don't forget to press Star ⭐️⭐️⭐️⭐️⭐️


